Preferences/__init__.py

branch
Py2 comp.
changeset 3484
645c12de6b0c
parent 3178
f25fc1364c88
parent 3354
8d69c9dfb5e2
child 3515
1b8381afe38f
--- a/Preferences/__init__.py	Sun Mar 30 22:00:14 2014 +0200
+++ b/Preferences/__init__.py	Thu Apr 03 23:05:31 2014 +0200
@@ -69,7 +69,7 @@
         "BreakAlways": False,
         "PythonInterpreter": "",
         "Python3Interpreter": "",
-        "RubyInterpreter": "/usr/bin/ruby",
+        "RubyInterpreter": "",
         "DebugClientType": "standard",
         # supported "standard", "threaded", "custom"
         "DebugClient": "",
@@ -476,6 +476,16 @@
         "WhitespaceBackground": QColor(Qt.white),
         "OnlineChangeTraceMarkerUnsaved": QColor("#ff8888"),
         "OnlineChangeTraceMarkerSaved": QColor("#88ff88"),
+        # colors for the marker map
+        "BookmarksMap": QColor("#f8c700"),
+        "ErrorsMap": QColor("#dd0000"),
+        "WarningsMap": QColor("#606000"),
+        "BreakpointsMap": QColor("#f55c07"),
+        "TasksMap": QColor("#2278f8"),
+        "CoverageMap": QColor("#ad3636"),
+        "ChangesMap": QColor("#00b000"),
+        "CurrentMap": QColor("#000000"),
+        "MarkerMapBackground": QColor("#e7e7e7"),
     }
     
     editorOtherFontsDefaults = {
@@ -910,6 +920,11 @@
         # 2 = weekly
         # 3 = monthly
         "CheckInstalledOnly": True,
+        # list of plug-ins not to shown in the repo dialog
+        "HiddenPlugins": [],
+        # parameters for housekeeping
+        "KeepGenerations": 2,
+        "KeepHidden": False,
     }
     
     # defaults for the printer settings
@@ -922,8 +937,8 @@
         "IconEditorState": QByteArray(),
     }
     
-    # defaults for py3flakes
-    py3flakesDefaults = {
+    # defaults for pyflakes
+    pyflakesDefaults = {
         "IncludeInSyntaxCheck": True,
         "IgnoreStarImportWarnings": True,
     }
@@ -2543,9 +2558,12 @@
     if key in ["DownloadPath"]:
         return prefClass.settings.value(
             "PluginManager/" + key, prefClass.pluginManagerDefaults[key])
-    elif key in ["UpdatesCheckInterval"]:
+    elif key in ["UpdatesCheckInterval", "KeepGenerations"]:
         return int(prefClass.settings.value(
             "PluginManager/" + key, prefClass.pluginManagerDefaults[key]))
+    elif key in ["HiddenPlugins"]:
+        return toList(prefClass.settings.value(
+            "PluginManager/" + key, prefClass.pluginManagerDefaults[key]))
     else:
         return toBool(prefClass.settings.value(
             "PluginManager/" + key, prefClass.pluginManagerDefaults[key]))
@@ -2624,7 +2642,7 @@
 
 def getFlakes(key, prefClass=Prefs):
     """
     Module function to retrieve the py3flakes related settings.
     
     @param key the key of the value to get
     @param prefClass preferences class used as the storage area
@@ -2632,15 +2650,15 @@
     """
     if key in ["IncludeInSyntaxCheck", "IgnoreStarImportWarnings"]:
         return toBool(prefClass.settings.value("Py3Flakes/" + key,
-                      prefClass.py3flakesDefaults[key]))
+                      prefClass.pyflakesDefaults[key]))
     else:
         return prefClass.settings.value(
-            "Py3Flakes/" + key, prefClass.py3flakesDefaults[key])
+            "Py3Flakes/" + key, prefClass.pyflakesDefaults[key])
     
 
 def setFlakes(key, value, prefClass=Prefs):
     """
     Module function to store the py3flakes related settings.
     
     @param key the key of the setting to be set
     @param value the value to be set
@@ -2624,7 +2642,7 @@
 def getFlakes(key, prefClass=Prefs):
     """
-    Module function to retrieve the py3flakes related settings.
+    Module function to retrieve the pyflakes related settings.
     
     @param key the key of the value to get
@@ -2632,15 +2650,15 @@
 def setFlakes(key, value, prefClass=Prefs):
     """
-    Module function to store the py3flakes related settings.
+    Module function to store the pyflakes related settings.
     
     @param key the key of the setting to be set

eric ide

mercurial